@@ -22,6 +22,20 @@ celery.config_from_object('render.celeryconfig')
 logger = logging.getLogger(__name__)
 
 
+def record_time(f):
+    def wrapper(*args, **kwargs):
+        begin = datetime.now()
+        logger.info(f"Rendering is started!")
+        try:
+            return f(*args, **kwargs)
+        finally:
+            end = datetime.now()
+            logger.info(f"Rendering is finished!")
+            logger.info(f"Took: {str(end - begin).split('.')[0]}")
+
+    return wrapper
+
+
 class FollowLog:
     BATCH_RENDER_NAME = re.compile(r'Batch render job being rendered:(.*)')
     COMPLETE = re.compile(r'Job Complete - Results in')
@@ -53,7 +67,7 @@ class FollowLog:
 
     def make_view_dir(self):
         directory = self.workdir / self.current_view
-        directory.mkdir(parents=True, exist_ok=True)
+        directory.mkdir(exist_ok=True)
         logger.info(f"Created directory - {directory}")
 
     def move_files(self):
@@ -131,7 +145,7 @@ class DestKey(Key):
     @property
     def workdir(self):
         directory = RENDER_DIR / self.scene_id.name / self.task_id.name
-        directory.mkdir(exist_ok=True)
+        directory.mkdir(parents=True, exist_ok=True)
         return directory
 
 
@@ -155,22 +169,24 @@ class Render:
                 f.extractall(self.texture.dst)
             logger.info(f"Texture unzipped to - {self.texture.dst}")
 
-    def run(self, extension):
-        assert extension in self.EXTENSIONS, f"{extension} is not supported"
-        logger.debug(f"Using {extension} for output files")
-
+    def download_scene(self):
         self.unpack_texture()
         self.client.download_file(self.scene.path, self.scene.localfile)
         logger.info(f"Scene downloaded - {self.scene.localfile}")
         if not self.scene.localfile.is_file():
             raise Exception("Local file does not exists")
 
+    @record_time
+    def run(self, batch_name, extension):
+        assert extension in self.EXTENSIONS, f"{extension} is not supported"
+        logger.debug(f"Using {extension} for output files")
+
         max_cmd = Path(os.environ['ADSK_3DSMAX_x64_2018']) / '3dsmaxcmd'
         args = [
             str(max_cmd),
             "-continueOnError",
-            "-batchRender",
-            f'-outputName:{str(self.dest.workdir / f"0.{extension}")}',
+            f"-batchRender:{batch_name}",
+            f'-outputName:{str(self.dest.workdir / f"{batch_name}.{extension}")}',
         ]
         if self.texture:
             logger.debug(f"Using textures: {list(self.texture.dst.glob('*'))}")
@@ -183,7 +199,7 @@ class Render:
         for file in follow.iterate_files(process.stdout):
             view = file.parent.name
             self.client.upload_file(
-                self.dest.task_id / 'result' / view / file.name,
+                self.dest.scene_id / 'result' / view / file.name,
                 file
             )
             logger.info(f"Artifact is uploaded - {file}")
@@ -191,20 +207,6 @@ class Render:
         return process.returncode
 
 
-def record_time(f):
-    def wrapper(*args, **kwargs):
-        begin = datetime.now()
-        logger.info(f"Rendering is started!")
-        try:
-            return f(*args, **kwargs)
-        finally:
-            end = datetime.now()
-            logger.info(f"Rendering is finished!")
-            logger.info(f"Took: {str(end - begin).split('.')[0]}")
-
-    return wrapper
-
-
 def collect_logs(dest: DestKey, client: S3):
     logger.info("Collecting log files...")
     for file in itertools.chain(
@@ -223,20 +225,25 @@ def run(
         scene_key: str,
         dest_key: str,
         texture: str = None,
-        extension: str = Render.DEFAULT_EXTENSION
+        extension: str = Render.DEFAULT_EXTENSION,
+        batch_renders: list = None
 ):
     dest = DestKey(dest_key)
     configure_logger(dest.workdir / 'task.log')
 
+    assert batch_renders, "batch_renders is not specifies"
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
 
     s3 = AWS_S3()
     scene = FileKey(dest.workdir, scene_key)
     render = Render(scene, dest, s3, texture and TextureFileKey(dest.workdir, texture))
+
     try:
-        rc = record_time(render.run)(extension)
-        if rc > 0:
-            raise Exception(f"3dsmax returned non zero code {rc}")
+        render.download_scene()
+        for batch_name in batch_renders:
+            rc = render.run(batch_name, extension)
+            if rc > 0:
+                raise Exception(f"3dsmax returned non zero code {rc}")
     except Exception as e:
         logger.exception(e)
         raise
