@@ -1,15 +1,14 @@
 import logging
 import time
 from argparse import ArgumentParser
-from functools import partial
-
-from render.watch.logs import collect_instance_logs
-from render.watch.screen import capture_screenshot
-from render.watch.window import WindowMgr
 
 from render import LOG_DIR
 from render.logger import configure_logger
 from render.s3 import AWS_S3
+from render.watch.logs import collect_instance_logs
+from render.watch.screen import capture_screenshot
+from render.watch.stat import log_usage
+from render.watch.window import WindowMgr
 
 logger = logging.getLogger(__name__)
 
@@ -19,16 +18,16 @@ def main(args):
 
     s3 = AWS_S3()
     w = WindowMgr()
-    functions = [
-        partial(w.find_window_wildcard, args.window_name),
-        w.foreground,
-        w.maximaze,
-        partial(capture_screenshot, s3),
-        partial(collect_instance_logs, s3)
-    ]
+
     while True:
-        for func in functions:
-            func()
+        w.find_window_wildcard(args.window_name)
+        w.foreground()
+        w.maximaze()
+
+        capture_screenshot(s3)
+        log_usage()
+
+        collect_instance_logs(s3)
 
         logger.debug(f"Waiting {args.delay} seconds")
         time.sleep(args.delay)
