@@ -14,14 +14,16 @@ def collect_instance_logs(client: S3):
     logger.debug("Collecting log files for instance...")
     for path in itertools.chain(
             # additional logs could be appended here
-            glob.glob(str(RENDER_DIR / '**' / '*.log')),
+            glob.glob(str(RENDER_DIR / '**' / '*.log'), recursive=True),
     ):
         file = Path(path)
         logger.debug(f"Found log {file}")
         try:
             file.relative_to(LOG_DIR)
         except ValueError:
-            filename = f"{file.parent.name}/{file.name}"
+            task = file.parent
+            scene = task.parent
+            filename = f"{scene.name}/{task.name}/{file.name}"
         else:
             filename = file.name
 
